@@ -2,7 +2,7 @@ import random
 from concurrent.futures import ThreadPoolExecutor
 from queue import Queue
 from threading import Lock
-from typing import List, Callable
+from typing import List, Callable, Optional, Any
 
 import requests
 from requests import Session
@@ -61,8 +61,9 @@ class ProxyManager:
                 return self._success / self._trials
 
     def proxy_session(self,
-                      fn: Callable[[Session], None],
-                      exception_handle: Callable[[ProxyInfo, Exception], None] = lambda info, ex: print(info, ex)) -> None:
+                      fn: Callable[[Session], Optional[Any]],
+                      callback_async: Callable[[Optional[Any]], None] = lambda x: None,
+                      exception_handle: Callable[[ProxyInfo, Exception], None] = lambda info, ex: print(info, ex)):
         def task():
             success = False
 
@@ -76,7 +77,12 @@ class ProxyManager:
                     timer = SimpleTimer()
                     try:
                         with timer:
-                            fn(session)
+                            result = fn(session)
+
+                        if type(result) is tuple:
+                            callback_async(*result)
+                        else:
+                            callback_async(result)
 
                         success = True
                     except Exception as ex:
